To remove all symbols and debug data from your application:

1. Open Xcode.
2. Open application project in Xcode.
3. Navigate to "File" > "Project Settings" in the Xcode menu bar.
4. Within the Project Settings window, find and select the "Deployment" tab.
5. Look for the setting named "Strip Debug Symbols During Copy".
6. Change the value of the "Strip Debug Symbols During Copy" setting to YES.
7. Save your changes.
8. Build your application.
